@@ -109,37 +109,19 @@ ci.mean <- function(x, sigma = NULL, sigma2 = NULL, alternative = c("two.sided",
 
   #......
   # Check if input 'x' is missing
-  if (isTRUE(missing(x))) {
-
-    stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
-         call. = FALSE)
-
-  }
+  if (isTRUE(missing(x))) { stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.", call. = FALSE) }
 
   #......
   # Check if input 'x' is NULL
-  if (isTRUE(is.null(x))) {
-
-    stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
-
-  }
+  if (isTRUE(is.null(x))) { stop("Input specified for the argument 'x' is NULL.", call. = FALSE) }
 
   #......
   # Check 'group'
   if (isTRUE(!is.null(group))) {
 
-    if (ncol(data.frame(group)) != 1) {
+    if (ncol(data.frame(group)) != 1L) { stop("More than one grouping variable specified for the argument 'group'.", call. = FALSE) }
 
-      stop("More than one grouping variable specified for the argument 'group'.", call. = FALSE)
-
-    }
-
-    if (nrow(data.frame(group)) != nrow(data.frame(x))) {
-
-      stop("Length of the vector or factor specified in the argument 'group' does not match with 'x'.",
-           call. = FALSE)
-
-    }
+    if (nrow(data.frame(group)) != nrow(data.frame(x))) { stop("Length of the vector or factor specified in the argument 'group' does not match with 'x'.", call. = FALSE) }
 
     # Convert group into a vector
     group <- unlist(group, use.names = FALSE)
@@ -150,18 +132,9 @@ ci.mean <- function(x, sigma = NULL, sigma2 = NULL, alternative = c("two.sided",
   # Check 'split'
   if (isTRUE(!is.null(split))) {
 
-    if (ncol(data.frame(split)) != 1) {
+    if (ncol(data.frame(split)) != 1L) { stop("More than one split variable specified for the argument 'split'.",call. = FALSE) }
 
-      stop("More than one split variable specified for the argument 'split'.",call. = FALSE)
-
-    }
-
-    if (nrow(data.frame(split)) != nrow(data.frame(x))) {
-
-      stop("Length of the vector or factor specified in the argument 'split' does not match with 'x'.",
-           call. = FALSE)
-
-    }
+    if (nrow(data.frame(split)) != nrow(data.frame(x))) { stop("Length of the vector or factor specified in the argument 'split' does not match with 'x'.", call. = FALSE) }
 
     # Convert 'split' into a vector
     split <- unlist(split, use.names = FALSE)
@@ -292,11 +265,7 @@ ci.mean <- function(x, sigma = NULL, sigma2 = NULL, alternative = c("two.sided",
 
   #......
   # Check input 'check'
-  if (isTRUE(!is.logical(check))) {
-
-    stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
-
-  }
+  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
 
   #----------------------------------------
 
@@ -304,29 +273,17 @@ ci.mean <- function(x, sigma = NULL, sigma2 = NULL, alternative = c("two.sided",
 
     #......
     # Check input 'sigma' and 'sigma2'
-    if (isTRUE(!is.null(sigma) && !is.null(sigma2))) {
-
-        stop("Please specify either argument 'sigma' or argument 'sigma2', but not both.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.null(sigma) && !is.null(sigma2))) { stop("Please specify either argument 'sigma' or argument 'sigma2', but not both.", call. = FALSE) }
 
     #......
     # Check input 'sigma'
     if (isTRUE(!is.null(sigma))) {
 
       # SD smaller or equal 0
-      if (isTRUE(any(sigma <= 0L))) {
-
-        stop("Please specify a numeric value grater than 0 for the argument 'sigma'.", call. = FALSE)
-
-      }
+      if (isTRUE(any(sigma <= 0L))) { stop("Please specify a numeric value grater than 0 for the argument 'sigma'.", call. = FALSE) }
 
       # Length of 'sigma'
-      if (isTRUE(length(sigma) != 1L)) {
-
-        stop("Please specify a numeric value for the argument 'sigma'.", call. = FALSE)
-
-      }
+      if (isTRUE(length(sigma) != 1L)) { stop("Please specify a numeric value for the argument 'sigma'.", call. = FALSE) }
 
     }
 
@@ -335,18 +292,10 @@ ci.mean <- function(x, sigma = NULL, sigma2 = NULL, alternative = c("two.sided",
     if (isTRUE(!is.null(sigma2))) {
 
       # Variance smaller or equal 0
-      if (isTRUE(any(sigma2 <= 0L))) {
-
-        stop("Please specify a numeric value grater than 0 for the argument 'sigma2'.", call. = FALSE)
-
-      }
+      if (isTRUE(any(sigma2 <= 0L))) { stop("Please specify a numeric value grater than 0 for the argument 'sigma2'.", call. = FALSE) }
 
       # Length of 'sigma2'
-      if (isTRUE(length(sigma2) != 1L)) {
-
-        stop("Please specify a numeric value for the argument 'sigma2'.", call. = FALSE)
-
-      }
+      if (isTRUE(length(sigma2) != 1L)) { stop("Please specify a numeric value for the argument 'sigma2'.", call. = FALSE) }
 
     }
 
@@ -361,46 +310,23 @@ ci.mean <- function(x, sigma = NULL, sigma2 = NULL, alternative = c("two.sided",
 
     #......
     # Check input 'conf.level'
-    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) {
-
-      stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.",
-           call. = FALSE)
-
-    }
+    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) { stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.", call. = FALSE) }
 
     #......
     # Check input 'group'
     if (isTRUE(!is.null(group))) {
 
       # Population standard deviation
-      if (isTRUE(!is.null(sigma))) {
-
-        stop("Grouping variable cannot be used for confidence intervals with known population standard deviation.",
-             call. = FALSE)
-
-      }
+      if (isTRUE(!is.null(sigma))) { stop("Grouping variable cannot be used for confidence intervals with known population standard deviation.", call. = FALSE) }
 
       # Population variance
-      if (isTRUE(!is.null(sigma2))) {
-
-        stop("Grouping variable cannot be used for confidence intervals with known population variance.",
-             call. = FALSE)
-
-      }
+      if (isTRUE(!is.null(sigma2))) { stop("Grouping variable cannot be used for confidence intervals with known population variance.", call. = FALSE) }
 
       # Input 'group' completely missing
-      if (isTRUE(all(is.na(group)))) {
-
-        stop("The grouping variable specified in 'group' is completely missing.", call. = FALSE)
-
-      }
+      if (isTRUE(all(is.na(group)))) { stop("The grouping variable specified in 'group' is completely missing.", call. = FALSE) }
 
       # Only one group in 'group'
-      if (isTRUE(length(na.omit(unique(group))) == 1L)) {
-
-        warning("There is only one group represented in the grouping variable specified in 'group'.", call. = FALSE)
-
-      }
+      if (isTRUE(length(na.omit(unique(group))) == 1L)) { warning("There is only one group represented in the grouping variable specified in 'group'.", call. = FALSE) }
 
     }
 
@@ -409,68 +335,34 @@ ci.mean <- function(x, sigma = NULL, sigma2 = NULL, alternative = c("two.sided",
     if (isTRUE(!is.null(split))) {
 
       # Population standard deviation
-      if (isTRUE(!is.null(sigma))) {
-
-        stop("Split variable cannot be used for confidence intervals with known population standard deviation.",
-             call. = FALSE)
-
-      }
+      if (isTRUE(!is.null(sigma))) { stop("Split variable cannot be used for confidence intervals with known population standard deviation.", call. = FALSE) }
 
       # Population variance
-      if (isTRUE(!is.null(sigma2))) {
-
-        stop("Split variable cannot be used for confidence intervals with known population variance.",
-             call. = FALSE)
-
-      }
+      if (isTRUE(!is.null(sigma2))) { stop("Split variable cannot be used for confidence intervals with known population variance.", call. = FALSE) }
 
       # Input 'split' completely missing
-      if (isTRUE(all(is.na(split)))) {
-
-        stop("The split variable specified in 'split' is completely missing.", call. = FALSE)
-
-      }
+      if (isTRUE(all(is.na(split)))) { stop("The split variable specified in 'split' is completely missing.", call. = FALSE) }
 
       # Only one group in 'split'
-      if (isTRUE(length(na.omit(unique(split))) == 1L)) {
-
-        warning("There is only one group represented in the split variable specified in 'split'.", call. = FALSE)
-
-      }
+      if (isTRUE(length(na.omit(unique(split))) == 1L)) { warning("There is only one group represented in the split variable specified in 'split'.", call. = FALSE) }
 
     }
 
     #......
     # Check input 'sort.var'
-    if (isTRUE(!is.logical(sort.var))) {
-
-      stop("Please specify TRUE or FALSE for the argument 'sort.var'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.logical(sort.var))) { stop("Please specify TRUE or FALSE for the argument 'sort.var'.", call. = FALSE) }
 
     #......
     # Check input 'na.omit'
-    if (isTRUE(!is.logical(na.omit))) {
-
-      stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.logical(na.omit))) { stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE) }
 
     #......
     # Check input 'digits'
-    if (isTRUE(digits %% 1L != 0L || digits < 0L)) {
-
-      stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE)
-
-    }
+    if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE) }
 
     #......
     # Check input 'output'
-    if (isTRUE(!is.logical(output))) {
-
-      stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
 
   }
 
