@@ -102,19 +102,11 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
   #......
   # Check input 'by'
-  if (isTRUE(missing(by))) {
-
-    stop("Please specify a character string for the argument 'by'.", call. = FALSE)
-
-  }
+  if (isTRUE(missing(by))) { stop("Please specify a character string for the argument 'by'.", call. = FALSE) }
 
   #......
   # Check input 'check'
-  if (isTRUE(!is.logical(check))) {
-
-    stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
-
-  }
+  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
 
   #----------------------------------------
 
@@ -122,59 +114,31 @@ df.merge <- function(..., by, all = TRUE, check = TRUE, output = TRUE) {
 
     #......
     # Same matching variable in each data frame
-    if (isTRUE(any(vapply(df, function(y) !by %in%  names(y), FUN.VALUE = logical(1L))))) {
-
-      stop("Data frames do not have the same matching variable specified in 'by'.", call. = FALSE)
-
-    }
+    if (isTRUE(any(vapply(df, function(y) !by %in%  names(y), FUN.VALUE = logical(1L))))) { stop("Data frames do not have the same matching variable specified in 'by'.", call. = FALSE) }
 
     #......
     # Same class
-    if (isTRUE(length(unique(vapply(df, function(y) class(y[, by]), FUN.VALUE = character(1L)))) != 1L)) {
-
-      stop("Matching variable in the data frames do not all have the same class.", call. = FALSE)
-
-    }
+    if (isTRUE(length(unique(vapply(df, function(y) class(y[, by]), FUN.VALUE = character(1L)))) != 1L)) { stop("Matching variable in the data frames do not all have the same class.", call. = FALSE) }
 
     #......
     # Duplicated values in the matching variable
-    if (isTRUE(any(vapply(df, function(y) anyDuplicated(na.omit(y[, by])), FUN.VALUE = 1L) != 0L))) {
-
-      stop("There are duplicated values in the matching variable specified in 'by'.", call. = FALSE)
-
-    }
+    if (isTRUE(any(vapply(df, function(y) anyDuplicated(na.omit(y[, by])), FUN.VALUE = 1L) != 0L))) { stop("There are duplicated values in the matching variable specified in 'by'.", call. = FALSE) }
 
     #......
     # Missing values in the matching variable
-    if (isTRUE(any(vapply(df, function(y) any(is.na(y[, by])), FUN.VALUE = logical(1L))))) {
-
-      stop("There are missing values in the matching variable specified in 'by'.", call. = FALSE)
-
-    }
+    if (isTRUE(any(vapply(df, function(y) any(is.na(y[, by])), FUN.VALUE = logical(1L))))) { stop("There are missing values in the matching variable specified in 'by'.", call. = FALSE) }
 
     #......
     # Duplicated variable names across the data frames
-    if (isTRUE(anyDuplicated(unlist(lapply(df, names))[unlist(lapply(df, names)) != by]) != 0L)) {
-
-      stop("There are duplicated variable names across data frames.", call. = FALSE)
-
-    }
+    if (isTRUE(anyDuplicated(unlist(lapply(df, names))[unlist(lapply(df, names)) != by]) != 0L)) { stop("There are duplicated variable names across data frames.", call. = FALSE) }
 
     #......
     # Check input 'all'
-    if (isTRUE(!is.logical(all))) {
-
-      stop("Please specify TRUE or FALSE for the argument 'all'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.logical(all))) { stop("Please specify TRUE or FALSE for the argument 'all'.", call. = FALSE) }
 
     #......
     # Check input 'output'
-    if (isTRUE(!is.logical(output))) {
-
-      stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
 
   }
 
